package
Version:
v0.0.0-...-24ce8d2
Opens a new window with list of versions in this module.
Published: Dec 8, 2025
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Result struct {
PrivateKeyDER []byte
CertificatesDER [][]byte
}
Result represents the decrypted contents of a Key-6.dat file.
Unprotect reads and decrypts a Key-6.dat file.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.